/*
 * NewConnectionSnippetHostResources.java
 *
 * Copyright (C) 2022 by RStudio, PBC
 *
 * Unless you have received this program directly from RStudio pursuant
 * to the terms of a commercial license agreement with RStudio, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */

package org.rstudio.studio.client.workbench.views.connections.res;

import com.google.gwt.core.client.GWT;
import com.google.gwt.resources.client.ClientBundle;
import com.google.gwt.resources.client.ImageResource;

public interface NewConnectionSnippetHostResources extends ClientBundle
{
   public static final NewConnectionSnippetHostResources INSTANCE = GWT.create(NewConnectionSnippetHostResources.class);
   
   @Source("connectionSettings.png")
   ImageResource configImage();

   @Source("connectionUninstall.png")
   ImageResource trashImage();

   @Source("connectionUninstall_2x.png")
   ImageResource trashImage2x();
}
